==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/WebTransactionServiceDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebTransactionServiceDescription } from "./WebTransactionServiceDescription";
/**
 * @hidden
 */
export let WebTransactionServiceDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebTransactionServiceDescriptionMetadata extends Base {
        static b(a) {
            if (WebTransactionServiceDescriptionMetadata.a == null) {
                WebTransactionServiceDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebTransactionServiceDescriptionMetadata.c(WebTransactionServiceDescriptionMetadata.a);
            }
            if (a.j(WebTransactionServiceDescriptionMetadata.a)) {
                return;
            }
            a.y(WebTransactionServiceDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:TransactionService");
        }
        static d(a) {
            WebTransactionServiceDescriptionMetadata.b(a);
            a.aa("WebTransactionService", () => new WebTransactionServiceDescription());
            a.z("WebTransactionService", WebTransactionServiceDescriptionMetadata.a);
        }
    }
    WebTransactionServiceDescriptionMetadata.$t = /*@__PURE__*/ markType(WebTransactionServiceDescriptionMetadata, 'WebTransactionServiceDescriptionMetadata');
    WebTransactionServiceDescriptionMetadata.a = null;
    return WebTransactionServiceDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/WebTransactionServiceDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebTransactionServiceDescription } from "./WebTransactionServiceDescription";
/**
 * @hidden
 */
export let WebTransactionServiceDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebTransactionServiceDescriptionMetadata extends Base {
        static b(a) {
            if (WebTransactionServiceDescriptionMetadata.a == null) {
                WebTransactionServiceDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebTransactionServiceDescriptionMetadata.c(WebTransactionServiceDescriptionMetadata.a);
            }
            if (a.k(WebTransactionServiceDescriptionMetadata.a)) {
                return;
            }
            a.aa(WebTransactionServiceDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:TransactionService");
        }
        static d(a) {
            WebTransactionServiceDescriptionMetadata.b(a);
            a.ac("WebTransactionService", () => new WebTransactionServiceDescription());
            a.ab("WebTransactionService", WebTransactionServiceDescriptionMetadata.a);
        }
    }
    WebTransactionServiceDescriptionMetadata.$t = /*@__PURE__*/ markType(WebTransactionServiceDescriptionMetadata, 'WebTransactionServiceDescriptionMetadata');
    WebTransactionServiceDescriptionMetadata.a = null;
    return WebTransactionServiceDescriptionMetadata;
})();
